@@ -1,23 +1,23 @@
 <?php
-// ե빹¸
+// t@CXVEۑ
 $filename = $MOWIKI_DATA.rawurlencode($gIn['title']).'.txt';
 
-// å
+// XV`FbN
 if (file_exists($filename)) {
   // if (filemtime($filename) > $gIn['ts']) {
-  if (filemtime($filename) > time()) {
-	// 顼
-	print "ERROR<br>åˤҤäޤ<br>֥饦äƲ";
+  if (filemtime($filename) > $gIn['ts']) {
+	// G[
+	print "ERROR<br>XV`FbNɂЂ܂<br>uEU̖߂Ŗ߂ĉ";
 	exit;
   }
 }
 
-if (file_exists($filename)) { // ե뤬¸ߤ
-  // ٺ
+if (file_exists($filename)) { // t@C݂ꍇ
+  // x폜
   unlink($filename);
 }
 
-// ե˽
+// t@Cɏ
 $fp = fopen($filename, 'a+');
 fputs($fp, $gIn['body']);
 fclose($fp);
